==> vtiger-4.0p1_1.tbz: www/vtiger/modules/System/includes/lang/cs.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: cs.php,v 1.1 2005/03/14 07:42:10 shankarr Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informace o systmu';

$text['vitals']         = 'Zkladn informace';
$text['hostname']       = 'Jmno potae';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verze jdra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Pihlench uivatel';
$text['loadavg']        = 'Prmrn zt';

$text['hardware']       = 'Hardwarov informace';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['mhz']            = 'Frekvence';
$text['cache']          = 'Velikost cache';
$text['bogomips']       = 'Bogomipsy';
$text['usb']            = 'USB zazen';
$text['pci']            = 'PCI zazen';
$text['ide']            = 'IDE zazen';
$text['scsi']           = 'SCSI zazen';

$text['netusage']       = 'Pouvn st';
$text['device']         = 'Zazen';
$text['received']       = 'Pijato';
$text['sent']           = 'Odeslno';
$text['errors']         = 'Chyby/Vyputno';

$text['memusage']       = 'Obsazen pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Pipojen souborov systmy';
$text['mount']          = 'Adres';
$text['partition']      = 'Oddl';

$text['percent']        = 'Obsazeno';
$text['type']           = 'Typ';
$text['free']           = 'Volno';
$text['used']           = 'Pouito';
$text['size']           = 'Velikost';
$text['totals']         = 'Celkem';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'dn';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablona';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odeslat';
$text['created']        = 'Vytvoeno pomoc';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'dn';
$text['hours']          = 'hodin';
$text['minutes']        = 'minut';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>

==> vtiger-4.2.4.tbz: www/vtiger/modules/System/includes/lang/cs.php <==
<?php
//
// phpSysInfo - A PHP System Information Script
// http://phpsysinfo.sourceforge.net/
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// $Id: cs.php,v 1.11 2004/08/30 15:51:26 webbie Exp $

$charset                = 'iso-8859-2';

$text['title']          = 'Informace o systmu';

$text['vitals']         = 'Zkladn informace';
$text['hostname']       = 'Jmno potae';
$text['ip']             = 'IP adresa';
$text['kversion']       = 'Verze jdra';
$text['dversion']       = 'Distro Name';
$text['uptime']         = 'Uptime';
$text['users']          = 'Pihlench uivatel';
$text['loadavg']        = 'Prmrn zt';

$text['hardware']       = 'Hardwarov informace';
$text['numcpu']         = 'Procesory';
$text['cpumodel']       = 'Model';
$text['cpuspeed']       = 'Frekvence';
$text['busspeed']       = 'BUS Speed';
$text['cache']          = 'Velikost cache';
$text['bogomips']       = 'Bogomipsy';

$text['pci']            = 'PCI zazen';
$text['ide']            = 'IDE zazen';
$text['scsi']           = 'SCSI zazen';
$text['usb']            = 'USB zazen';

$text['netusage']       = 'Pouvn st';
$text['device']         = 'Zazen';
$text['received']       = 'Pijato';
$text['sent']           = 'Odeslno';
$text['errors']         = 'Chyby/Vyputno';

$text['memusage']       = 'Obsazen pamti';
$text['phymem']         = 'Fyzick pam';
$text['swap']           = 'Swap';

$text['fs']             = 'Pipojen souborov systmy';
$text['mount']          = 'Adres';
$text['partition']      = 'Oddl';

$text['percent']        = 'Obsazeno';
$text['type']           = 'Typ';
$text['free']           = 'Volno';
$text['used']           = 'Pouito';
$text['size']           = 'Velikost';
$text['totals']         = 'Celkem';

$text['kb']             = 'KB';
$text['mb']             = 'MB';
$text['gb']             = 'GB';

$text['none']           = 'dn';

$text['capacity']       = 'Kapacita';

$text['template']       = 'ablona';
$text['language']       = 'Jazyk';
$text['submit']         = 'Odeslat';
$text['created']        = 'Vytvoeno pomoc';
$text['locale']         = 'en_US';
$text['gen_time']       = 'on %b %d, %Y at %r';

$text['days']           = 'dn';
$text['hours']          = 'hodin';
$text['minutes']        = 'minut';
  
$text['temperature']    = 'Temperature';
$text['voltage']        = 'Voltage';
$text['fans']           = 'Fans';
$text['s_value']        = 'Value';
$text['s_min']          = 'Min';
$text['s_max']          = 'Max';
$text['s_div']          = 'Div';
$text['hysteresis']     = 'Hysteresis';
$text['s_limit']        = 'Limit';
$text['s_label']        = 'Label';
$text['degree_mark']    = '&ordm;C';
$text['voltage_mark']   = 'V';
$text['rpm_mark']       = 'RPM';

?>
